searchData={"content_type":"text/markdown","items":[{"doc":"[![Build Status](https://github.com/Betree/burnex/workflows/Test/badge.svg)](https://github.com/Betree/burnex/actions)\n[![Coverage Status](https://coveralls.io/repos/github/Betree/burnex/badge.svg?branch=master)](https://coveralls.io/github/Betree/burnex?branch=master)\n[![Module Version](https://img.shields.io/hexpm/v/burnex.svg)](https://hex.pm/packages/burnex)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/burnex/)\n[![Total Download](https://img.shields.io/hexpm/dt/burnex.svg)](https://hex.pm/packages/burnex)\n[![License](https://img.shields.io/hexpm/l/burnex.svg)](https://hex.pm/packages/burnex)\n[![Last Updated](https://img.shields.io/github/last-commit/Betree/burnex.svg)](https://github.com/Betree/burnex/commits/master)\n\nCompare an email address against 3900+ burner email domains (temporary email\nproviders) based on this list from\n[https://github.com/wesbos/burner-email-providers](https://github.com/wesbos/burner-email-providers).","ref":"Burnex.html","title":"Burnex","type":"module"},{"doc":"Add `:burnex` to your list of dependencies in `mix.exs`.\n\n```elixir\ndef deps do\n  [\n    {:burnex, \"~> 3.1.0\"}\n  ]\nend\n```","ref":"Burnex.html#module-installation","title":"Installation - Burnex","type":"module"},{"doc":"Be aware that Burnex will not check if the email is RFC compliant, it will only\ncheck the domain (everything that comes after `@`).\n\n```elixir\niex> Burnex.is_burner?(\"my-email@gmail.com\")\nfalse\niex> Burnex.is_burner?(\"my-email@yopmail.fr\")\ntrue\niex> Burnex.is_burner? \"invalid.format.yopmail.fr\"\nfalse\niex> Burnex.is_burner? \"\\\"this is a valid address! crazy right ?\\\"@yopmail.fr\"\ntrue\n\niex> Burnex.providers |> MapSet.member?(\"yopmail.fr\")\ntrue\n```\n\n#","ref":"Burnex.html#module-usage","title":"Usage - Burnex","type":"module"},{"doc":"Following code ensures email has a valid format then check if it belongs to a burner provider:\n\n```elixir\ndef changeset(model, params) do\n  model\n  |> cast(params, @required_fields ++ @optional_fields)\n  |> validate_required([:email])\n  |> validate_email()\nend\n\n@email_regex ~r/\\A([\\w+\\-].?)+@[a-z\\d\\-]+(\\.[a-z]+)*\\.[a-z]+\\z/i\n\ndefp validate_email(%{changes: %{email: email}} = changeset) do\n  case Regex.match?(@email_regex, email) do\n    true ->\n      case Burnex.is_burner?(email) do\n        true -> add_error(changeset, :email, \"forbidden_provider\")\n        false -> changeset\n      end\n    false -> add_error(changeset, :email, \"invalid_format\")\n  end\nend\ndefp validate_email(changeset), do: changeset\n```\n\n#","ref":"Burnex.html#module-with-an-ecto-changeset","title":"With an Ecto changeset - Burnex","type":"module"},{"doc":"As an extra precaution against newly-created burner domains,\nyou can use Burnex to do MX record DNS resolution.\nThis is done like this:\n\n```\niex> Burnex.check_domain_mx_record(\"gmail.com\")\n:ok\niex> Burnex.check_domain_mx_record(\"gmail.dklfsd\")\n{:error, \"Cannot find MX records\"}\n```\n\nHere is an example function to check if an email is valid:\n\n```elixir\n  # Use a regex capture to get the \"domain\" part of an email\n  @email_regex ~r/^\\S+@(\\S+\\.\\S+)$/\n\n  # hard-code some trusted domains to avoid checking their MX record every time\n  @good_email_domains [\n    \"gmail.com\",\n    \"fastmail.com\"\n  ]\n\n  defp email_domain(email), do: Regex.run(@email_regex, String.downcase(email))\n\n  defp is_not_burner?(email, domain) do\n    with {:is_burner, false} <- {:is_burner, Burnex.is_burner?(email)},\n         {:check_mx_record, :ok} <- {:check_mx_record, Burnex.check_domain_mx_record(domain)} do\n      true\n    else\n      {:is_burner, true} ->\n        {false, \"forbidden email\"}\n\n      {:check_mx_record, {:error, error_message}} when is_binary(error_message) ->\n        {false, error_message}\n\n      {:check_mx_record, :error} ->\n        {false, \"forbidden provider\"}\n    end\n  end\n\n  @spec is_valid?(String.t()) :: true | {false, String.t()}\n  def is_valid?(email) do\n    case email_domain(email) do\n      [_ | [domain]] when domain in @good_email_domains ->\n        true\n\n      [_ | [domain]] ->\n        is_not_burner?(email, domain)\n\n      _ ->\n        {false, \"Email in bad format\"}\n    end\n  end\n```","ref":"Burnex.html#module-mx-record-dns-resolution","title":"MX record DNS resolution - Burnex","type":"module"},{"doc":"This software is licensed under MIT license. Copyright (c) 2018- Benjamin Piouffle.","ref":"Burnex.html#module-license","title":"License - Burnex","type":"module"},{"doc":"","ref":"Burnex.html#check_domain_mx_record/2","title":"Burnex.check_domain_mx_record/2","type":"function"},{"doc":"Check if email is a temporary / burner address.\n\nOptionally resolve the MX record","ref":"Burnex.html#is_burner?/2","title":"Burnex.is_burner?/2","type":"function"},{"doc":"* providers - (set of domains) this option specifies\n burner email domains to match against. Defaults to:\n [list of domains](https://github.com/Betree/burnex/blob/master/priv/burner-email-providers/emails.txt)","ref":"Burnex.html#is_burner?/2-options","title":"Options - Burnex.is_burner?/2","type":"function"},{"doc":"iex> Burnex.is_burner?(\"my-email@gmail.com\")\n    false\n    iex> Burnex.is_burner?(\"my-email@yopmail.fr\")\n    true\n    iex> Burnex.is_burner? \"invalid.format.yopmail.fr\"\n    false","ref":"Burnex.html#is_burner?/2-examples","title":"Examples - Burnex.is_burner?/2","type":"function"},{"doc":"Check a domain is a burner domain.","ref":"Burnex.html#is_burner_domain?/2","title":"Burnex.is_burner_domain?/2","type":"function"},{"doc":"* providers - (set of domains) this option specifies\n burner email domains to match against. Defaults to:\n [list of domains](https://github.com/Betree/burnex/blob/master/priv/burner-email-providers/emails.txt)","ref":"Burnex.html#is_burner_domain?/2-options","title":"Options - Burnex.is_burner_domain?/2","type":"function"},{"doc":"iex> Burnex.is_burner_domain?(\"yopmail.fr\")\n    true\n    iex> Burnex.is_burner_domain?(\"\")\n    false\n    iex> Burnex.is_burner_domain?(\"gmail.com\")\n    false","ref":"Burnex.html#is_burner_domain?/2-examples","title":"Examples - Burnex.is_burner_domain?/2","type":"function"},{"doc":"Returns a MapSet with all blocked domains providers.","ref":"Burnex.html#providers/0","title":"Burnex.providers/0","type":"function"},{"doc":"iex> Burnex.providers() |> MapSet.member?(\"yopmail.fr\")\n    true","ref":"Burnex.html#providers/0-examples","title":"Examples - Burnex.providers/0","type":"function"},{"doc":"# Changelog","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"* Remove dns dependency in favor of erlang's :inet_res module #80\n* feature: customize providers #78\n* update emails list\n* update dependencies","ref":"changelog.html#3-2-0","title":"3.2.0 - Changelog","type":"extras"},{"doc":"* Update dependencies (thanks @dolfinus)\n* Fix CI (thanks @dolfinus)\n* Update providers (thanks @robsonpeixoto)","ref":"changelog.html#3-1-0","title":"3.1.0 - Changelog","type":"extras"},{"doc":"* Separate MX Record check from core functionality #52 - @peaceful-james\n* Misc doc changes (#47) - @kianmeng\n* Fixed doctests","ref":"changelog.html#3-0-0","title":"3.0.0 - Changelog","type":"extras"},{"doc":"* Add option to resolve MX records (#50) - thanks @peaceful-james","ref":"changelog.html#2-2-0","title":"2.2.0 - Changelog","type":"extras"},{"doc":"* Validate subdomains (#46) - thanks @peaceful-james\n* Update dependencies\n* Update domains","ref":"changelog.html#2-1-0-2020-11-08","title":"2.1.0 (2020-11-08) - Changelog","type":"extras"},{"doc":"* Breaking changes\n  - Improve performances by using a MapSet (#37) - thanks @tomciopp!\n  - `Burnex.provider/0` returns a MapSet instead of a list.","ref":"changelog.html#2-0-0-2020-09-28","title":"2.0.0 (2020-09-28) - Changelog","type":"extras"},{"doc":"* Fix build issue, missing VERSION in release (#33).","ref":"changelog.html#1-2-1-2020-08-03","title":"1.2.1 (2020-08-03) - Changelog","type":"extras"},{"doc":"* Update dependencies\n* Update providers list\n* Update docs","ref":"changelog.html#1-2-0-2020-07-30","title":"1.2.0 (2020-07-30) - Changelog","type":"extras"},{"doc":"* Breaking changes\n  - Change `is_burner_domain/1` to `is_burner_domain?/1`","ref":"changelog.html#1-1-0-2018-08-29","title":"1.1.0 (2018-08-29) - Changelog","type":"extras"},{"doc":"* Enhancements\n  - Add `is_burner_domain/1` function to check the domain directly\n  - Update providers list","ref":"changelog.html#1-0-5-2018-08-29","title":"1.0.5 (2018-08-29) - Changelog","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}